<?php

class fatoraRedirectModuleFrontController extends ModuleFrontController {

    public $fatora;

    public $url = 'https://maktapp.credit/v3/AddTransaction';

    public function postProcess() {

        $theCart                        = $this->context->cart;
        $cartId                         = $theCart->id;
        Context::getContext()->currency = new Currency((int) Context::getContext()->cart->id_currency);
        Context::getContext()->language = new Language((int) Context::getContext()->customer->id_lang);
        $secureKey                      = Context::getContext()->customer->secure_key;
        $paymentStatus                  = Configuration::get('PS_OS_PREPARATION');

        $moduleName = $this->module->displayName;
        $currencyId = (int) Context::getContext()->currency->id;
        $amount     = (float) $theCart->getOrderTotal(true, Cart::BOTH);

        $this->module->validateOrder($cartId, $paymentStatus, $amount, $moduleName, '', array(), $currencyId, false, $secureKey);
        $orderId     = Order::getOrderByCartId($cartId);
        $orderObject = new Order((int) $orderId);
        //$orderRef    = $orderObject->reference;

        $payLoadData = $this->getPayLoadData($orderObject, $cartId  ,$orderId );
   // var_dump($payLoadData);
        $this->restoreCart($cartId);
        try {
            $url      = $this->generatePaymentURL($payLoadData);
            Tools::redirect($url);
        } catch (Exception $ex) {
            
            if (version_compare(_PS_VERSION_, '1.7.0', '>')) {
                $this->errors[] = $ex->getMessage();
                $this->redirectWithNotifications('index.php?controller=order');
            } else {
                $message = $ex->getMessage();
                array_push($this->errors, $this->module->l($message));
                $this->context->smarty->assign('errors', array($message));
                return $this->setTemplate('error.tpl');
            }
        }
    }

    protected function getPayLoadData($orderObject, $cartId , $orderId) {
        $address   = new Address((int) ($orderObject->id_address_delivery));
        $customer  = new Customer((int) ($address->id_customer));
        $phone     = $address->phone_mobile;
        $secureKey = $customer->secure_key;
        $fName     = $customer->firstname;
        $lname     = $customer->lastname;
        $email     = $customer->email;
        //$orderRef  = $orderObject->reference;
        if (empty($phone)) {
            $phone = $address->phone;
        }

        $customerAddress = array(
            "Address" => $address->address1 . ' , ' . $address->address2,
        );

        $amount          = $orderObject->total_paid;
        $returnURL       = $this->context->link->getModuleLink('fatora',
                'confirmation'
        );
         $apiKey     = Configuration::get('fatora_token');

        $curlData = [
            'token'=> $apiKey,
            'orderId'=>$cartId,
            'CustomerName'       => "$fName $lname",
            'customerPhone'     => $phone,
            'CustomerEmail'      => $email,
            'customerCountry'    => $customerAddress,
            'currencyCode' => Context::getContext()->currency->iso_code,
            'amount'       => $amount,
            'SuccessUrl'        => $returnURL,
            'FailureURL'           => $returnURL,
            'lang'           => Context::getContext()->language->iso_code, 

        ];
        return $curlData;
    }

    public function restoreCart($cartId) {
        $oldCart                        = new Cart($cartId);
        $duplication                    = $oldCart->duplicate();
        $this->context->cookie->id_cart = $duplication['cart']->id;
        $context                        = $this->context;
        $context->cart                  = $duplication['cart'];
        CartRule::autoAddToCart($context);
        $this->context->cookie->write();
    }

    public function curl_post($url, array $post = NULL, array $options = array())
    {
        $defaults = array(
            CURLOPT_POST           => 1,
            CURLOPT_HEADER         => 0,
            CURLOPT_URL            => $url,
            CURLOPT_FRESH_CONNECT  => 1,
            CURLOPT_RETURNTRANSFER => 1,
            CURLOPT_FORBID_REUSE   => 1,
            CURLOPT_TIMEOUT        => 500,
            CURLOPT_POSTFIELDS     => http_build_query($post)
        );
        $ch = curl_init();
        curl_setopt_array($ch, ($options + $defaults));
        if( ! $result = curl_exec($ch))
        {
            trigger_error(curl_error($ch));
        }
        curl_close($ch);
        return $result;
    }

    public function generatePaymentURL($payLoadData){
        $response = $this->curl_post( $this->url , $payLoadData );
        $data_json_decode = json_decode($response);
        $result = $data_json_decode->{'result'};
        return $result;
    }

}
